summaryrefslogtreecommitdiffstats
path: root/Core/User/UserProviderInterface.php
diff options
context:
space:
mode:
Diffstat (limited to 'Core/User/UserProviderInterface.php')
-rw-r--r--Core/User/UserProviderInterface.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/Core/User/UserProviderInterface.php b/Core/User/UserProviderInterface.php
index 6c5666f..79be191 100644
--- a/Core/User/UserProviderInterface.php
+++ b/Core/User/UserProviderInterface.php
@@ -28,7 +28,7 @@ interface UserProviderInterface
* @throws UsernameNotFoundException if the user is not found
* @param string $username The username
*
- * @return AccountInterface
+ * @return UserInterface
*/
function loadUserByUsername($username);
@@ -39,12 +39,12 @@ interface UserProviderInterface
* from the database, or if it simply merges the passed User into the
* identity map of an entity manager.
*
* @throws UnsupportedAccountException if the account is not supported
* @param AccountInterface $account
*
- * @return AccountInterface
+ * @return UserInterface
*/
- function loadUserByAccount(AccountInterface $account);
+ function loadUser(UserInterface $user);
/**
* Whether this provider supports the given user class
@@ -39,12 +39,12 @@ interface UserProviderInterface
* identity map of an entity manager.
*
- * @throws UnsupportedAccountException if the account is not supported
- * @param AccountInterface $account
+ * @throws UnsupportedUserException if the account is not supported
+ * @param UserInterface $user
*